@@ -1,5 +1,3 @@
-use FindBin;
-use lib "$FindBin::Bin/../lib";
 use Mojolicious::Lite;
 
 websocket '/test' => sub {
@@ -33,7 +31,7 @@ __DATA__
         ws.onmessage = function (event) {
           document.body.innerHTML += JSON.parse(event.data).test;
         };
-        ws.onopen = function (event) {
+        ws.onopen = function () {
           ws.send(JSON.stringify({test: 'WebSocket support works! ♥'}));
         };
       }
